Module value

Module value 

Structs

AttributeName
ConditionName
OutputExportName

Enums

ExpBool
ExpPair
ExpString
ExpStringList

Constants

AWS_ACCOUNT_ID
AWS account ID (e.g., “123456789012”)
AWS_NOTIFICATION_ARNS
List of SNS topic ARNs for stack notifications
AWS_PARTITION
AWS partition (e.g., “aws”, “aws-cn”, “aws-us-gov”)
AWS_REGION
AWS region (e.g., “us-east-1”)
AWS_STACK_ID
Stack ID/ARN
AWS_STACK_NAME
Stack name
AWS_URL_SUFFIX
AWS domain suffix (e.g., “amazonaws.com”)

Traits

FnFindInMap
Trait for expression types that support find in map (Fn::FindInMap) expressions
FnIf
Trait for expression types that support conditional (Fn::If) expressions
FnSelect
Trait for expression types that support select (Fn::Select) expressions
ToValue

Functions

equals_bool
equals_string
fn_cidr
Helper function to create a Fn::Cidr expression
fn_find_in_map
Generic helper function to create find in map (Fn::FindInMap) expressions
fn_find_in_map_bool
Type-specific helper for boolean find in map expressions that doesn’t require turbofish syntax. Use this when working with ExpBool values.
fn_find_in_map_string
Type-specific helper for string find in map expressions that doesn’t require turbofish syntax. Use this when working with ExpString values.
fn_get_azs
Helper function to create a Fn::GetAZs expression
fn_if
Generic helper function to create conditional (Fn::If) expressions
fn_if_bool
Type-specific helper for boolean conditional expressions that doesn’t require turbofish syntax. Use this when working with ExpBool values.
fn_select
Generic helper function to create select (Fn::Select) expressions
fn_select_bool
Type-specific helper for boolean select expressions that doesn’t require turbofish syntax. Use this when working with ExpBool values.
fn_select_string
Type-specific helper for string select expressions that doesn’t require turbofish syntax. Use this when working with ExpString values.
fn_split
Helper function to create a split expression
get_att
get_att_arn
join
mk_name