Structs
Enums
Constants
- AWS_
ACCOUNT_ ID - AWS account ID (e.g., “123456789012”)
- AWS_
NOTIFICATION_ ARNS - List of SNS topic ARNs for stack notifications
- AWS_
PARTITION - AWS partition (e.g., “aws”, “aws-cn”, “aws-us-gov”)
- AWS_
REGION - AWS region (e.g., “us-east-1”)
- AWS_
STACK_ ID - Stack ID/ARN
- AWS_
STACK_ NAME - Stack name
- AWS_
URL_ SUFFIX - AWS domain suffix (e.g., “amazonaws.com”)
Traits
- FnFind
InMap - Trait for expression types that support find in map (
Fn::FindInMap) expressions - FnIf
- Trait for expression types that support conditional (
Fn::If) expressions - FnSelect
- Trait for expression types that support select (
Fn::Select) expressions - ToValue
Functions
- equals_
bool - equals_
string - fn_cidr
- Helper function to create a Fn::Cidr expression
- fn_
find_ in_ map - Generic helper function to create find in map (
Fn::FindInMap) expressions - fn_
find_ in_ map_ bool - Type-specific helper for boolean find in map expressions that doesn’t require turbofish syntax. Use this when working with ExpBool values.
- fn_
find_ in_ map_ string - Type-specific helper for string find in map expressions that doesn’t require turbofish syntax. Use this when working with ExpString values.
- fn_
get_ azs - Helper function to create a Fn::GetAZs expression
- fn_if
- Generic helper function to create conditional (
Fn::If) expressions - fn_
if_ bool - Type-specific helper for boolean conditional expressions that doesn’t require turbofish syntax. Use this when working with ExpBool values.
- fn_
select - Generic helper function to create select (
Fn::Select) expressions - fn_
select_ bool - Type-specific helper for boolean select expressions that doesn’t require turbofish syntax. Use this when working with ExpBool values.
- fn_
select_ string - Type-specific helper for string select expressions that doesn’t require turbofish syntax. Use this when working with ExpString values.
- fn_
split - Helper function to create a split expression
- get_att
- get_
att_ arn - join
- mk_name